@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 package Data::Visitor;
-use Squirrel;
+use Any::Moose;
 
 use Scalar::Util qw/blessed refaddr reftype weaken isweak/;
 use overload ();
@@ -16,7 +16,7 @@ use namespace::clean -except => 'meta';
 # the double not makes this no longer undef, so exempt from useless constant warnings in older perls
 use constant DEBUG => not not our $DEBUG || $ENV{DATA_VISITOR_DEBUG};
 
-our $VERSION = "0.22";
+our $VERSION = "0.24";
 
 has tied_as_objects => (
 	isa => "Bool",
